==> dde-grand-search_5.2.3.orig.tar.xz: dde-grand-search-5.2.3/translations/dde-grand-search_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
<context>
    <name>AudioPreviewPlugin</name>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="71"/>
        <source>Artist:</source>
        <translation>Sanatçı:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="83"/>
        <source>Album:</source>
        <translation>Albüm:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="108"/>
        <source>Duration:</source>
        <translation>Süre:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="123"/>
        <source>Type:</source>
        <translation>Tür:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="135"/>
        <source>Location:</source>
        <translation>Konum:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="149"/>
        <source>Time modified:</source>
        <translation>Zaman değiştirildi:</translation>
    </message>
</context>
<context>
    <name>DdeGrandSearchDockPlugin</name>
    <message>
        <location filename="../src/grand-search-dock-plugin/ddegrandsearchdockplugin.cpp" line="57"/>
        <location filename="../src/grand-search-dock-plugin/ddegrandsearchdockplugin.cpp" line="100"/>
        <source>Grand Search</source>
        <translation>Büyük Ara</translation>
    </message>
    <message>
        <location filename="../src/grand-search-dock-plugin/ddegrandsearchdockplugin.cpp" line="163"/>
        <source>Search settings</source>
        <translation>Arama ayarları</translation>
    </message>
</context>
<context>
    <name>EntranceWidget</name>
    <message>
        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="241"/>
        <source>Search</source>
        <translation>Ara</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="242"/>
        <source>What would you like to search for?</source>
        <translation>Ne aramak istersin?</translation>
    </message>
</context>
<context>
    <name>EntranceWidgetPrivate</name>
    <message>
        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="94"/>
        <source>Cut</source>
        <translation>Kes</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="98"/>
        <source>Copy</source>
        <translation>Kopyala</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="102"/>
        <source>Paste</source>
        <translation>Yapıştır</translation>
    </message>
</context>
<context>
    <name>GeneralPreviewPlugin</name>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalpreviewplugin.cpp" line="208"/>
        <source>Location:</source>
        <translation>Konum:</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalpreviewplugin.cpp" line="219"/>
        <source>Time modified:</source>
        <translation>Zaman değiştirildi:</translation>
    </message>
</context>
<context>
    <name>GeneralToolBar</name>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/generaltoolbar.cpp" line="85"/>
        <source>Open</source>
        <translation>Aç</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/generaltoolbar.cpp" line="90"/>
        <source>Open Path</source>
        <translation>Yolu Aç</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/generaltoolbar.cpp" line="95"/>
        <source>Copy Path</source>
        <translation>Yolu Kopyala</translation>
    </message>
</context>
<context>
    <name>GroupWidget</name>
    <message>
        <location filename="../src/grand-search/gui/exhibition/matchresult/groupwidget.cpp" line="261"/>
        <source>More</source>
        <translation>Daha fazla</translation>
    </message>
</context>
<context>
    <name>ImagePreviewPlugin</name>
    <message>
        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="67"/>
        <source>Dimensions:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="83"/>
        <source>Type:</source>
        <translation>Tür:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="98"/>
        <source>Size:</source>
        <translation>Boyut:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="110"/>
        <source>Location:</source>
        <translation>Konum:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="124"/>
        <source>Time modified:</source>
        <translation>Zaman değiştirildi:</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/grand-search/gui/mainwindow.cpp" line="217"/>
        <source>No search results</source>
        <translation>Arama sonucu bulunamadı</translation>
    </message>
</context>
<context>
    <name>MatchWidget</name>
    <message>
        <location filename="../src/grand-search/gui/exhibition/matchresult/matchwidget.cpp" line="89"/>
        <source>Search for &quot;%1&quot;</source>
        <translation>&quot;%1&quot; için ara</translation>
    </message>
</context>
<context>
    <name>PlanWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="43"/>
        <source>Search experience program</source>
        <translation>Arama deneyimi programı</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="51"/>
        <source>Join search experience program</source>
        <translation>Arama deneyimi programına katılın</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="63"/>
        <source>Joining the search experience program means that you grant and authorize us to collect the information of your device and system, file icons, content and properties, applications and their configurations. If you refuse our collection and use of the aforementioned information, do not join the program.</source>
        <translation>Arama deneyimi programına katılmak, cihazınızın ve sisteminizin, dosya simgelerinin, içeriğin ve özelliklerin, uygulamaların ve yapılandırmalarının bilgilerini toplamamız için bize yetki verdiğiniz anlamına gelir. Yukarıda belirtilen bilgileri toplamamızı ve kullanmamızı reddederseniz, programa katılmazsınız.</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="71"/>
        <source>To know more about the management of your data, please refer to the UnionTech Software Privacy Policy (</source>
        <translation>Verilerinizin yönetimi hakkında daha fazla bilgi için lütfen UnionTech Yazılım Gizlilik Politikasına bakın (</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="73"/>
        <source>https://www.uniontech.com/agreement/privacy-en</source>
        <translation>https://www.uniontech.com/agreement/privacy-en</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="74"/>
        <source>https://www.deepin.org/en/agreement/privacy/</source>
        <translation>https://www.deepin.org/en/agreement/privacy/</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="76"/>
        <source>).</source>
        <translation>).</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="41"/>
        <source>Applications</source>
        <translation>Uygulamalar</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="42"/>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="43"/>
        <source>Videos</source>
        <translation>Videolar</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="44"/>
        <source>Music</source>
        <translation>Müzik</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="45"/>
        <source>Pictures</source>
        <translation>Resimler</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="46"/>
        <source>Documents</source>
        <translation>Belgeler</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="47"/>
        <source>Folders</source>
        <translation>Klasörler</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="48"/>
        <source>Files</source>
        <translation>Dosyalar</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="49"/>
        <source>Web</source>
        <translation>Ağ</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="38"/>
        <source>Dimensions:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="39"/>
        <source>Type:</source>
        <translation>Tür:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="40"/>
        <source>Size:</source>
        <translation>Boyut:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="41"/>
        <source>Duration:</source>
        <translation>Süre:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="42"/>
        <source>Location:</source>
        <translation>Konum:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="43"/>
        <source>Time modified:</source>
        <translation>Zaman değiştirildi:</translation>
    </message>
</context>
<context>
    <name>ScopeWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/scopewidget.cpp" line="44"/>
        <source>Search contents</source>
        <translation>İçerikler ara</translation>
    </message>
</context>
</TS>

==> dde-grand-search_5.3.1.orig.tar.xz: dde-grand-search-5.3.1/translations/dde-grand-search_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
<context>
    <name>AudioPreviewPlugin</name>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="71"/>
        <source>Artist:</source>
        <translation>Sanatçı:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="83"/>
        <source>Album:</source>
        <translation>Albüm:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="108"/>
        <source>Duration:</source>
        <translation>Süre:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="123"/>
        <source>Type:</source>
        <translation>Tür:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="135"/>
        <source>Location:</source>
        <translation>Konum:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="149"/>
        <source>Time modified:</source>
        <translation>Zaman değiştirildi:</translation>
    </message>
</context>
<context>
    <name>CustomWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/customwidget.cpp" line="38"/>
        <source>Custom search</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DdeGrandSearchDockPlugin</name>
    <message>
        <location filename="../src/grand-search-dock-plugin/ddegrandsearchdockplugin.cpp" line="57"/>
        <location filename="../src/grand-search-dock-plugin/ddegrandsearchdockplugin.cpp" line="100"/>
        <source>Grand Search</source>
        <translation>Büyük Ara</translation>
    </message>
    <message>
        <location filename="../src/grand-search-dock-plugin/ddegrandsearchdockplugin.cpp" line="163"/>
        <source>Search settings</source>
        <translation>Arama ayarları</translation>
    </message>
</context>
<context>
    <name>EntranceWidget</name>
    <message>
        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="241"/>
        <source>Search</source>
        <translation>Ara</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="242"/>
        <source>What would you like to search for?</source>
        <translation>Ne aramak istersin?</translation>
    </message>
</context>
<context>
    <name>EntranceWidgetPrivate</name>
    <message>
        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="94"/>
        <source>Cut</source>
        <translation>Kes</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="98"/>
        <source>Copy</source>
        <translation>Kopyala</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="102"/>
        <source>Paste</source>
        <translation>Yapıştır</translation>
    </message>
</context>
<context>
    <name>GeneralPreviewPlugin</name>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalpreviewplugin.cpp" line="208"/>
        <source>Location:</source>
        <translation>Konum:</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalpreviewplugin.cpp" line="219"/>
        <source>Time modified:</source>
        <translation>Zaman değiştirildi:</translation>
    </message>
</context>
<context>
    <name>GeneralToolBar</name>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/generaltoolbar.cpp" line="85"/>
        <source>Open</source>
        <translation>Aç</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/generaltoolbar.cpp" line="90"/>
        <source>Open Path</source>
        <translation>Yolu Aç</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/generaltoolbar.cpp" line="95"/>
        <source>Copy Path</source>
        <translation>Yolu Kopyala</translation>
    </message>
</context>
<context>
    <name>GroupWidget</name>
    <message>
        <location filename="../src/grand-search/gui/exhibition/matchresult/groupwidget.cpp" line="254"/>
        <source>More</source>
        <translation>Daha fazla</translation>
    </message>
</context>
<context>
    <name>ImagePreviewPlugin</name>
    <message>
        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="67"/>
        <source>Dimensions:</source>
        <translation>Boyutlar:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="83"/>
        <source>Type:</source>
        <translation>Tür:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="98"/>
        <source>Size:</source>
        <translation>Boyut:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="110"/>
        <source>Location:</source>
        <translation>Konum:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="124"/>
        <source>Time modified:</source>
        <translation>Zaman değiştirildi:</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/grand-search/gui/mainwindow.cpp" line="224"/>
        <source>No search results</source>
        <translation>Arama sonucu bulunamadı</translation>
    </message>
</context>
<context>
    <name>MatchWidget</name>
    <message>
        <location filename="../src/grand-search/gui/exhibition/matchresult/matchwidget.cpp" line="88"/>
        <source>Search for &quot;%1&quot;</source>
        <translation>&quot;%1&quot; için ara</translation>
    </message>
</context>
<context>
    <name>PlanWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="43"/>
        <source>Search experience program</source>
        <translation>Arama deneyimi programı</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="51"/>
        <source>Join search experience program</source>
        <translation>Arama deneyimi programına katılın</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="63"/>
        <source>Joining the search experience program means that you grant and authorize us to collect the information of your device and system, file icons, content and properties, applications and their configurations. If you refuse our collection and use of the aforementioned information, do not join the program.</source>
        <translation>Arama deneyimi programına katılmak, cihazınızın ve sisteminizin, dosya simgelerinin, içeriğin ve özelliklerin, uygulamaların ve yapılandırmalarının bilgilerini toplamamız için bize yetki verdiğiniz anlamına gelir. Yukarıda belirtilen bilgileri toplamamızı ve kullanmamızı reddederseniz, programa katılmazsınız.</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="71"/>
        <source>To know more about the management of your data, please refer to the UnionTech Software Privacy Policy (</source>
        <translation>Verilerinizin yönetimi hakkında daha fazla bilgi için lütfen UnionTech Yazılım Gizlilik Politikasına bakın (</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="73"/>
        <source>https://www.uniontech.com/agreement/privacy-en</source>
        <translation>https://www.uniontech.com/agreement/privacy-en</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="74"/>
        <source>https://www.deepin.org/en/agreement/privacy/</source>
        <translation>https://www.deepin.org/en/agreement/privacy/</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="76"/>
        <source>).</source>
        <translation>).</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="41"/>
        <source>Best match</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="42"/>
        <source>Applications</source>
        <translation>Uygulamalar</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="43"/>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="44"/>
        <source>Videos</source>
        <translation>Videolar</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="45"/>
        <source>Music</source>
        <translation>Müzik</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="46"/>
        <source>Pictures</source>
        <translation>Resimler</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="47"/>
        <source>Documents</source>
        <translation>Belgeler</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="48"/>
        <source>Folders</source>
        <translation>Klasörler</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="49"/>
        <source>Files</source>
        <translation>Dosyalar</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="50"/>
        <source>Web</source>
        <translation>Ağ</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="38"/>
        <source>Dimensions:</source>
        <translation>Boyutlar:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="39"/>
        <source>Type:</source>
        <translation>Tür:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="40"/>
        <source>Size:</source>
        <translation>Boyut:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="41"/>
        <source>Duration:</source>
        <translation>Süre:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="42"/>
        <source>Location:</source>
        <translation>Konum:</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="43"/>
        <source>Time modified:</source>
        <translation>Zaman değiştirildi:</translation>
    </message>
    <message>
        <location filename="../src/grand-search-daemon/searcher/file/filesearchutils.cpp" line="215"/>
        <source>modified</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ScopeWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/scopewidget.cpp" line="44"/>
        <source>Search contents</source>
        <translation>İçerikler ara</translation>
    </message>
</context>
<context>
    <name>TailerWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="33"/>
        <source>Tailer settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="42"/>
        <source>It is displayed at the end of search results for better identification and distinction of items with duplicate names.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="50"/>
        <source>Parent directory</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="52"/>
        <source>Time modified</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
